# Appletree
A high-Performance Program simuLatEs and fiTs REsponse of xEnon.

[![Test package](https://github.com/XENONnT/appletree/actions/workflows/pytest.yml/badge.svg?branch=master)](https://github.com/XENONnT/appletree/actions/workflows/pytest.yml)
[![Coverage Status](https://coveralls.io/repos/github/XENONnT/appletree/badge.svg)](https://coveralls.io/github/XENONnT/appletree)
[![PyPI version shields.io](https://img.shields.io/pypi/v/appletree.svg)](https://pypi.python.org/pypi/appletree/)
[![Readthedocs Badge](https://readthedocs.org/projects/appletree/badge/?version=latest)](https://appletree.readthedocs.io/en/latest/?badge=latest)
[![CodeFactor](https://www.codefactor.io/repository/github/xenonnt/appletree/badge)](https://www.codefactor.io/repository/github/xenonnt/appletree)

## Installation and Set-Up

### Regular installation:
```
pip install appletree
```

### Developer setup:
Clone the repository:

```
git clone https://github.com/XENONnT/appletree
cd appletree
```
Install the requirements in your environment:
```
pip install -r requirements.txt
```

Then install the package:
```
python setup.py install --user
```
You are now good to go!

## Usage
The best way to start with the `appletree` package is to have a look at the tutorial `notebooks`. 

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.
